You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@activemq.apache.org by ta...@apache.org on 2009/05/21 12:26:17 UTC

svn commit: r777039 [15/15] - in /activemq/activemq-cpp/trunk/activemq-cpp/src/main: activemq/cmsutil/ activemq/commands/ activemq/exceptions/ activemq/io/ activemq/transport/ activemq/transport/failover/ activemq/transport/mock/ activemq/transport/tcp...

Modified: activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/nio/ReadOnlyBufferException.h
URL: http://svn.apache.org/viewvc/activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/nio/ReadOnlyBufferException.h?rev=777039&r1=777038&r2=777039&view=diff
==============================================================================
--- activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/nio/ReadOnlyBufferException.h (original)
+++ activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/nio/ReadOnlyBufferException.h Thu May 21 10:26:09 2009
@@ -55,11 +55,11 @@
          * Constructor - Initializes the file name and line number where
          * this message occurred.  Sets the message to report, using an
          * optional list of arguments to parse into the message
-         * @param file name where exception occurs
-         * @param line number where the exception occurred.
+         * @param file The file name where exception occurs
+         * @param lineNumber The line number where the exception occurred.
          * @param cause The exception that was the cause for this one to be thrown.
-         * @param message to report
-         * @param list of primitives that are formatted into the message
+         * @param msg The message to report
+         * @param ... list of primitives that are formatted into the message
          */
         ReadOnlyBufferException( const char* file, const int lineNumber,
                                  const std::exception* cause,
@@ -84,9 +84,10 @@
 
         /**
          * Constructor
-         * @param file name of the file were the exception occured.
-         * @param lineNumber line where the exception occured
-         * @param msg the message that was generated
+         * @param file The file name where exception occurs
+         * @param lineNumber The line number where the exception occurred.
+         * @param msg The message to report
+         * @param ... list of primitives that are formatted into the message
          */
         ReadOnlyBufferException( const char* file, const int lineNumber,
                                   const char* msg, ... ) throw()

Modified: activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/nio/ShortBuffer.h
URL: http://svn.apache.org/viewvc/activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/nio/ShortBuffer.h?rev=777039&r1=777038&r2=777039&view=diff
==============================================================================
--- activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/nio/ShortBuffer.h (original)
+++ activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/nio/ShortBuffer.h Thu May 21 10:26:09 2009
@@ -259,7 +259,7 @@
         /**
          * This method transfers the entire content of the given source shorts array into
          * this buffer.  This is the same as calling put( &buffer[0], 0, buffer.size()
-         * @pparam buffer - The buffer whose contents are copied to this ShortBuffer
+         * @param buffer - The buffer whose contents are copied to this ShortBuffer
          * @returns a reference to this buffer
          * @throws BufferOverflowException - If there is insufficient space in this buffer
          * @throws ReadOnlyBufferException - If this buffer is read-only
@@ -359,7 +359,7 @@
          * buffer's capacity will be array.length, its position will be offset, its limit
          * will be offset + length, and its mark will be undefined. Its backing array
          * will be the given array, and its array offset will be zero.
-         * @param buffer - The array that will back the new buffer
+         * @param array - The array that will back the new buffer
          * @param offset - The offset of the subarray to be used
          * @param length - The length of the subarray to be used
          * @returns a new ShortBuffer that is backed by buffer, caller owns.

Modified: activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/security/GeneralSecurityException.h
URL: http://svn.apache.org/viewvc/activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/security/GeneralSecurityException.h?rev=777039&r1=777038&r2=777039&view=diff
==============================================================================
--- activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/security/GeneralSecurityException.h (original)
+++ activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/security/GeneralSecurityException.h Thu May 21 10:26:09 2009
@@ -18,6 +18,7 @@
 #ifndef _DECAF_SECURITY_GENERALSECURITYEXCEPTION_H_
 #define _DECAF_SECURITY_GENERALSECURITYEXCEPTION_H_
 
+#include <decaf/util/Config.h>
 #include <decaf/lang/Exception.h>
 
 namespace decaf{
@@ -65,7 +66,7 @@
          * @param file The file name where exception occurs
          * @param lineNumber The line number where the exception occurred.
          * @param cause The exception that was the cause for this one to be thrown.
-         * @param message The Message string to report
+         * @param msg The message to report
          * @param ... list of primitives that are formatted into the message
          */
         GeneralSecurityException( const char* file, const int lineNumber,

Modified: activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/security/InvalidKeyException.h
URL: http://svn.apache.org/viewvc/activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/security/InvalidKeyException.h?rev=777039&r1=777038&r2=777039&view=diff
==============================================================================
--- activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/security/InvalidKeyException.h (original)
+++ activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/security/InvalidKeyException.h Thu May 21 10:26:09 2009
@@ -27,8 +27,7 @@
      * This is the exception for invalid Keys (invalid encoding, wrong length,
      * uninitialized, etc).
      */
-    class DECAF_API InvalidKeyException : public KeyException
-    {
+    class DECAF_API InvalidKeyException : public KeyException {
     public:
 
         /**
@@ -62,11 +61,11 @@
          * Constructor - Initializes the file name and line number where
          * this message occurred.  Sets the message to report, using an
          * optional list of arguments to parse into the message
-         * @param file name where exception occurs
-         * @param line number where the exception occurred.
+         * @param file The file name where exception occurs
+         * @param lineNumber The line number where the exception occurred.
          * @param cause The exception that was the cause for this one to be thrown.
-         * @param message to report
-         * @param list of primitives that are formatted into the message
+         * @param msg The message to report
+         * @param ... list of primitives that are formatted into the message
          */
         InvalidKeyException( const char* file, const int lineNumber,
                              const std::exception* cause,

Modified: activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/security/Key.h
URL: http://svn.apache.org/viewvc/activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/security/Key.h?rev=777039&r1=777038&r2=777039&view=diff
==============================================================================
--- activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/security/Key.h (original)
+++ activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/security/Key.h Thu May 21 10:26:09 2009
@@ -20,28 +20,29 @@
 
 #include <vector>
 #include <string>
+#include <decaf/util/Config.h>
 
 namespace decaf {
 namespace security {
 
     /**
-     * The Key interface is the top-level interface for all keys. It defines the 
-     * functionality shared by all key objects. All keys have three 
+     * The Key interface is the top-level interface for all keys. It defines the
+     * functionality shared by all key objects. All keys have three
      * characteristics:<br>
      * <br>
      * An Algorithm <br>
-     * This is the key algorithm for that key. The key algorithm is usually an 
-     * encryption or asymmetric operation algorithm (such as DSA or RSA), which 
-     * will work with those algorithms and with related algorithms (such as MD5 
-     * with RSA, SHA-1 with RSA, Raw DSA, etc.) The name of the algorithm of a 
+     * This is the key algorithm for that key. The key algorithm is usually an
+     * encryption or asymmetric operation algorithm (such as DSA or RSA), which
+     * will work with those algorithms and with related algorithms (such as MD5
+     * with RSA, SHA-1 with RSA, Raw DSA, etc.) The name of the algorithm of a
      * key is obtained using the getAlgorithm method.<br>
      * <br>
      * An Encoded Form <br>
-     * This is an external encoded form for the key used when a standard 
-     * representation of the key is needed outside the application, as 
-     * when transmitting the key to some other party. The key is encoded 
-     * according to a standard format (such as X.509 SubjectPublicKeyInfo or 
-     * PKCS#8), and is returned using the getEncoded method. Note: The syntax of 
+     * This is an external encoded form for the key used when a standard
+     * representation of the key is needed outside the application, as
+     * when transmitting the key to some other party. The key is encoded
+     * according to a standard format (such as X.509 SubjectPublicKeyInfo or
+     * PKCS#8), and is returned using the getEncoded method. Note: The syntax of
      * the ASN.1 type SubjectPublicKeyInfo is defined as follows:
      * <br>
      * SubjectPublicKeyInfo ::= SEQUENCE { <br>
@@ -52,7 +53,7 @@
      *    algorithm OBJECT IDENTIFIER, <br>
      *    parameters ANY DEFINED BY algorithm OPTIONAL } <br>
      * <br>
-     * For more information, see RFC 2459: Internet X.509 Public Key 
+     * For more information, see RFC 2459: Internet X.509 Public Key
      * Infrastructure Certificate and CRL Profile. <br>
      * <br>
      * A Format <br>
@@ -60,40 +61,40 @@
      * getFormat method.
      */
     class DECAF_API Key {
-        
+
     public:
-        
+
         virtual ~Key() {}
- 
+
         /**
-         * Returns the standard algorithm name for this key. For example, "DSA" 
+         * Returns the standard algorithm name for this key. For example, "DSA"
          * would indicate that this key is a DSA key.
-         * 
+         *
          * @return the name of the algorithm associated with this key.
          */
         virtual std::string getAlgorithm() const = 0;
-        
+
         /**
-         * Provides the key in its primary encoding format, or nothing if this 
+         * Provides the key in its primary encoding format, or nothing if this
          * key does not support encoding.
-         * 
+         *
          * @param output
-         *      Receives the encoded key, or nothing if the key does not support 
+         *      Receives the encoded key, or nothing if the key does not support
          *      encoding.
          */
         virtual void getEncoded( std::vector<unsigned char>& output) const = 0;
-        
+
         /**
-         * Returns the name of the primary encoding format of this key, or 
-         * an empty string if this key does not support encoding. The primary 
-         * encoding format is named in terms of the appropriate ASN.1 data 
-         * format, if an ASN.1 specification for this key exists. For example, 
-         * the name of the ASN.1 data format for public keys is 
-         * SubjectPublicKeyInfo, as defined by the X.509 standard; in this 
-         * case, the returned format is "X.509". Similarly, the name of the 
-         * ASN.1 data format for private keys is PrivateKeyInfo, as defined by 
+         * Returns the name of the primary encoding format of this key, or
+         * an empty string if this key does not support encoding. The primary
+         * encoding format is named in terms of the appropriate ASN.1 data
+         * format, if an ASN.1 specification for this key exists. For example,
+         * the name of the ASN.1 data format for public keys is
+         * SubjectPublicKeyInfo, as defined by the X.509 standard; in this
+         * case, the returned format is "X.509". Similarly, the name of the
+         * ASN.1 data format for private keys is PrivateKeyInfo, as defined by
          * the PKCS #8 standard; in this case, the returned format is "PKCS#8".
-         * 
+         *
          * @return the primary encoding format of the key.
          */
         virtual std::string getFormat() const = 0;

Modified: activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/security/KeyException.h
URL: http://svn.apache.org/viewvc/activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/security/KeyException.h?rev=777039&r1=777038&r2=777039&view=diff
==============================================================================
--- activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/security/KeyException.h (original)
+++ activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/security/KeyException.h Thu May 21 10:26:09 2009
@@ -18,6 +18,7 @@
 #ifndef _DECAF_SECURITY_KEYEXCEPTION_H_
 #define _DECAF_SECURITY_KEYEXCEPTION_H_
 
+#include <decaf/util/Config.h>
 #include <decaf/security/GeneralSecurityException.h>
 
 namespace decaf{
@@ -26,8 +27,7 @@
     /*
      * A basic key exception
      */
-    class DECAF_API KeyException : public GeneralSecurityException
-    {
+    class DECAF_API KeyException : public GeneralSecurityException {
     public:
 
         /**
@@ -61,11 +61,11 @@
          * Constructor - Initializes the file name and line number where
          * this message occurred.  Sets the message to report, using an
          * optional list of arguments to parse into the message
-         * @param file name where exception occurs
-         * @param line number where the exception occurred.
+         * @param file The file name where exception occurs
+         * @param lineNumber The line number where the exception occurred.
          * @param cause The exception that was the cause for this one to be thrown.
-         * @param message to report
-         * @param list of primitives that are formatted into the message
+         * @param msg The message to report
+         * @param ... list of primitives that are formatted into the message
          */
         KeyException( const char* file, const int lineNumber,
                       const std::exception* cause,

Modified: activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/security/NoSuchAlgorithmException.h
URL: http://svn.apache.org/viewvc/activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/security/NoSuchAlgorithmException.h?rev=777039&r1=777038&r2=777039&view=diff
==============================================================================
--- activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/security/NoSuchAlgorithmException.h (original)
+++ activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/security/NoSuchAlgorithmException.h Thu May 21 10:26:09 2009
@@ -62,11 +62,11 @@
          * Constructor - Initializes the file name and line number where
          * this message occurred.  Sets the message to report, using an
          * optional list of arguments to parse into the message
-         * @param file name where exception occurs
-         * @param line number where the exception occurred.
+         * @param file The file name where exception occurs
+         * @param lineNumber The line number where the exception occurred.
          * @param cause The exception that was the cause for this one to be thrown.
-         * @param message to report
-         * @param list of primitives that are formatted into the message
+         * @param msg The message to report
+         * @param ... list of primitives that are formatted into the message
          */
         NoSuchAlgorithmException( const char* file, const int lineNumber,
                                   const std::exception* cause,

Modified: activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/security/NoSuchProviderException.h
URL: http://svn.apache.org/viewvc/activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/security/NoSuchProviderException.h?rev=777039&r1=777038&r2=777039&view=diff
==============================================================================
--- activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/security/NoSuchProviderException.h (original)
+++ activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/security/NoSuchProviderException.h Thu May 21 10:26:09 2009
@@ -18,6 +18,7 @@
 #ifndef _DECAF_SECURITY_NOSUCHPROVIDEREXCEPTION_H_
 #define _DECAF_SECURITY_NOSUCHPROVIDEREXCEPTION_H_
 
+#include <decaf/util/Config.h>
 #include <decaf/security/GeneralSecurityException.h>
 
 namespace decaf{
@@ -62,11 +63,11 @@
          * Constructor - Initializes the file name and line number where
          * this message occurred.  Sets the message to report, using an
          * optional list of arguments to parse into the message
-         * @param file name where exception occurs
-         * @param line number where the exception occurred.
+         * @param file The file name where exception occurs
+         * @param lineNumber The line number where the exception occurred.
          * @param cause The exception that was the cause for this one to be thrown.
-         * @param message to report
-         * @param list of primitives that are formatted into the message
+         * @param msg The message to report
+         * @param ... list of primitives that are formatted into the message
          */
         NoSuchProviderException( const char* file, const int lineNumber,
                                  const std::exception* cause,

Modified: activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/security/Principal.h
URL: http://svn.apache.org/viewvc/activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/security/Principal.h?rev=777039&r1=777038&r2=777039&view=diff
==============================================================================
--- activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/security/Principal.h (original)
+++ activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/security/Principal.h Thu May 21 10:26:09 2009
@@ -18,33 +18,35 @@
 #ifndef _DECAF_SECURITY_PRINCIPAL_H_
 #define _DECAF_SECURITY_PRINCIPAL_H_
 
+#include <decaf/util/Config.h>
+
 namespace decaf {
 namespace security {
 
     /**
-     * Base interface for a principal, which can represent an individual or 
+     * Base interface for a principal, which can represent an individual or
      * organization.
      */
-    class Principal {        
+    class DECAF_API Principal {
     public:
-        
+
         virtual ~Principal() {}
-        
+
         /**
          * Compares two principals to see if they are the same.
-         * 
+         *
          * @param another
          *      A principal to be tested for equality to this one.
          * @return true if the given principal is equivalent to this one.
          */
         virtual bool equals( const Principal& another ) const = 0;
-        
+
         /**
          * Provides the name of this principal.
-         * 
+         *
          * @return the name of this principal.
          */
-        virtual std::string getName() const = 0;        
+        virtual std::string getName() const = 0;
     };
 }}
 

Modified: activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/security/PublicKey.h
URL: http://svn.apache.org/viewvc/activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/security/PublicKey.h?rev=777039&r1=777038&r2=777039&view=diff
==============================================================================
--- activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/security/PublicKey.h (original)
+++ activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/security/PublicKey.h Thu May 21 10:26:09 2009
@@ -19,18 +19,19 @@
 #define _DECAF_SECURITY_PUBLICKEY_H_
 
 #include <decaf/security/Key.h>
+#include <decaf/util/Config.h>
 
 namespace decaf {
 namespace security {
 
     /**
-     * A public key. This interface contains no methods or constants. It merely 
+     * A public key. This interface contains no methods or constants. It merely
      * serves to group (and provide type safety for) all public key interfaces.
      */
     class DECAF_API PublicKey : public Key {
-        
+
     public:
-        
+
         virtual ~PublicKey() {}
     };
 

Modified: activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/security/SignatureException.h
URL: http://svn.apache.org/viewvc/activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/security/SignatureException.h?rev=777039&r1=777038&r2=777039&view=diff
==============================================================================
--- activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/security/SignatureException.h (original)
+++ activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/security/SignatureException.h Thu May 21 10:26:09 2009
@@ -18,6 +18,7 @@
 #ifndef _DECAF_SECURITY_SIGNATUREEXCEPTION_H_
 #define _DECAF_SECURITY_SIGNATUREEXCEPTION_H_
 
+#include <decaf/util/Config.h>
 #include <decaf/security/GeneralSecurityException.h>
 
 namespace decaf{
@@ -61,11 +62,11 @@
          * Constructor - Initializes the file name and line number where
          * this message occurred.  Sets the message to report, using an
          * optional list of arguments to parse into the message
-         * @param file name where exception occurs
-         * @param line number where the exception occurred.
+         * @param file The file name where exception occurs
+         * @param lineNumber The line number where the exception occurred.
          * @param cause The exception that was the cause for this one to be thrown.
-         * @param message to report
-         * @param list of primitives that are formatted into the message
+         * @param msg The message to report
+         * @param ... list of primitives that are formatted into the message
          */
         SignatureException( const char* file, const int lineNumber,
                           const std::exception* cause,

Modified: activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/security/cert/Certificate.h
URL: http://svn.apache.org/viewvc/activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/security/cert/Certificate.h?rev=777039&r1=777038&r2=777039&view=diff
==============================================================================
--- activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/security/cert/Certificate.h (original)
+++ activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/security/cert/Certificate.h Thu May 21 10:26:09 2009
@@ -20,6 +20,8 @@
 
 #include <vector>
 
+#include <decaf/util/Config.h>
+
 #include <decaf/security/InvalidKeyException.h>
 #include <decaf/security/NoSuchAlgorithmException.h>
 #include <decaf/security/SignatureException.h>
@@ -35,101 +37,101 @@
      * Base interface for all identity certificates.
      */
     class DECAF_API Certificate {
-    
+
     public:
-        
+
         virtual ~Certificate() {}
-        
+
         /**
          * Compares the encoded form of the two certificates.
-         * 
+         *
          * @param cert
          *      The certificate to be tested for equality with this certificate.
          * @return true if the given certificate is equal to this certificate.
          */
         virtual bool equals( const Certificate& cert ) const = 0;
-        
+
         /**
          * Provides the encoded form of this certificate.
-         * 
+         *
          * @param output
          *      Receives the encoded form of this certificate.
          * @throws CertificateEncodingException if an encoding error occurs
          */
-        virtual void getEncoded( std::vector<unsigned char>& output ) const 
+        virtual void getEncoded( std::vector<unsigned char>& output ) const
             throw ( CertificateEncodingException ) = 0;
-        
+
         /**
          * Returns the type of this certificate
-         * 
+         *
          * @return the type of this certificate
          */
         virtual std::string getType() const = 0;
-        
+
         /**
          * Gets the public key of this certificate.
-         * 
+         *
          * @return the public key
          */
         virtual PublicKey* getPublicKey() = 0;
-        
+
         /**
          * Gets the public key of this certificate.
-         * 
+         *
          * @return the public key
          */
         virtual const PublicKey* getPublicKey() const = 0;
-        
+
         /**
          * Verifies that this certificate was signed with the private key
          * that corresponds to the specified public key.
-         * 
+         *
          * @param publicKey
          *      The public key used to carry out the validation.
-         * @throws NoSuchAlgorithmException - on unsupported signature algorithms. 
-         * @throws InvalidKeyException - on incorrect key. 
-         * @throws NoSuchProviderException - if there's no default provider. 
-         * @throws SignatureException - on signature errors. 
+         * @throws NoSuchAlgorithmException - on unsupported signature algorithms.
+         * @throws InvalidKeyException - on incorrect key.
+         * @throws NoSuchProviderException - if there's no default provider.
+         * @throws SignatureException - on signature errors.
          * @throws CertificateException - on encoding errors.
          */
-        virtual void verify( const PublicKey& publicKey ) const 
-            throw( NoSuchAlgorithmException, 
-                   InvalidKeyException, 
-                   NoSuchProviderException, 
-                   SignatureException, 
+        virtual void verify( const PublicKey& publicKey ) const
+            throw( NoSuchAlgorithmException,
+                   InvalidKeyException,
+                   NoSuchProviderException,
+                   SignatureException,
                    CertificateException) = 0;
-        
+
         /**
          * Verifies that this certificate was signed with the private key
          * that corresponds to the specified public key.  Uses the verification
          * engine of the specified provider.
-         * 
+         *
          * @param publicKey
          *      The public key used to carry out the validation.
          * @param sigProvider
          *      The name of the signature provider
-         * @throws NoSuchAlgorithmException - on unsupported signature algorithms. 
-         * @throws InvalidKeyException - on incorrect key. 
-         * @throws NoSuchProviderException - if there's no default provider. 
-         * @throws SignatureException - on signature errors. 
+         * @throws NoSuchAlgorithmException - on unsupported signature algorithms.
+         * @throws InvalidKeyException - on incorrect key.
+         * @throws NoSuchProviderException - if there's no default provider.
+         * @throws SignatureException - on signature errors.
          * @throws CertificateException - on encoding errors.
          */
-        virtual void verify( const PublicKey& publicKey, 
-                             const std::string& sigProvider ) const 
-                    throw( NoSuchAlgorithmException, 
-                           InvalidKeyException, 
-                           NoSuchProviderException, 
-                           SignatureException, 
+        virtual void verify( const PublicKey& publicKey,
+                             const std::string& sigProvider ) const
+                    throw( NoSuchAlgorithmException,
+                           InvalidKeyException,
+                           NoSuchProviderException,
+                           SignatureException,
                            CertificateException) = 0;
-        
+
         /**
          * Returns a string representation of this certificate.
-         * 
+         *
          * @return a string representation of this certificate
          */
         virtual std::string toString() const = 0;
     };
-    
+
 }}}
 
 #endif /*_DECAF_SECURITY_CERT_CERTIFICATE_H_*/

Modified: activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/security/cert/CertificateEncodingException.h
URL: http://svn.apache.org/viewvc/activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/security/cert/CertificateEncodingException.h?rev=777039&r1=777038&r2=777039&view=diff
==============================================================================
--- activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/security/cert/CertificateEncodingException.h (original)
+++ activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/security/cert/CertificateEncodingException.h Thu May 21 10:26:09 2009
@@ -18,6 +18,7 @@
 #ifndef _DECAF_SECURITY_CERT_CERTIFICATEENCODINGEXCEPTION_H_
 #define _DECAF_SECURITY_CERT_CERTIFICATEENCODINGEXCEPTION_H_
 
+#include <decaf/util/Config.h>
 #include <decaf/security/cert/CertificateException.h>
 
 namespace decaf{
@@ -25,7 +26,7 @@
 namespace cert{
 
     /*
-     * Certificate Encoding Exception. This is thrown whenever an error occurs 
+     * Certificate Encoding Exception. This is thrown whenever an error occurs
      * while attempting to encode a certificate.
      */
     class DECAF_API CertificateEncodingException : public CertificateException
@@ -63,8 +64,8 @@
          * Constructor - Initializes the file name and line number where
          * this message occured.  Sets the message to report, using an
          * optional list of arguments to parse into the message
-         * 
-         * @param file 
+         *
+         * @param file
          *      name where exception occurs
          * @param lineNumber
          *      line number where the exception occurred.
@@ -90,7 +91,7 @@
          * Clones this exception.  This is useful for cases where you need
          * to preserve the type of the original exception as well as the message.
          * All subclasses should override.
-         * 
+         *
          * @return A deep copy of this exception.
          */
         virtual CertificateEncodingException* clone() const{

Modified: activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/security/cert/CertificateException.h
URL: http://svn.apache.org/viewvc/activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/security/cert/CertificateException.h?rev=777039&r1=777038&r2=777039&view=diff
==============================================================================
--- activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/security/cert/CertificateException.h (original)
+++ activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/security/cert/CertificateException.h Thu May 21 10:26:09 2009
@@ -18,6 +18,7 @@
 #ifndef _DECAF_SECURITY_CERT_CERTIFICATEEXCEPTION_H_
 #define _DECAF_SECURITY_CERT_CERTIFICATEEXCEPTION_H_
 
+#include <decaf/util/Config.h>
 #include <decaf/security/GeneralSecurityException.h>
 
 namespace decaf{
@@ -62,8 +63,8 @@
          * Constructor - Initializes the file name and line number where
          * this message occured.  Sets the message to report, using an
          * optional list of arguments to parse into the message
-         * 
-         * @param file 
+         *
+         * @param file
          *      name where exception occurs
          * @param lineNumber
          *      line number where the exception occurred.
@@ -89,7 +90,7 @@
          * Clones this exception.  This is useful for cases where you need
          * to preserve the type of the original exception as well as the message.
          * All subclasses should override.
-         * 
+         *
          * @return A deep copy of this exception.
          */
         virtual CertificateException* clone() const{

Modified: activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/security/cert/CertificateExpiredException.h
URL: http://svn.apache.org/viewvc/activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/security/cert/CertificateExpiredException.h?rev=777039&r1=777038&r2=777039&view=diff
==============================================================================
--- activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/security/cert/CertificateExpiredException.h (original)
+++ activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/security/cert/CertificateExpiredException.h Thu May 21 10:26:09 2009
@@ -18,6 +18,7 @@
 #ifndef _DECAF_SECURITY_CERT_CERTIFICATEEXPIREDEXCEPTION_H_
 #define _DECAF_SECURITY_CERT_CERTIFICATEEXPIREDEXCEPTION_H_
 
+#include <decaf/util/Config.h>
 #include <decaf/security/cert/CertificateException.h>
 
 namespace decaf{
@@ -25,8 +26,8 @@
 namespace cert{
 
     /*
-     * Certificate Expired Exception. This is thrown whenever the current Date 
-     * or the specified Date is after the notAfter date/time specified in the 
+     * Certificate Expired Exception. This is thrown whenever the current Date
+     * or the specified Date is after the notAfter date/time specified in the
      * validity period of the certificate.
      */
     class DECAF_API CertificateExpiredException : public CertificateException
@@ -64,8 +65,8 @@
          * Constructor - Initializes the file name and line number where
          * this message occured.  Sets the message to report, using an
          * optional list of arguments to parse into the message
-         * 
-         * @param file 
+         *
+         * @param file
          *      name where exception occurs
          * @param lineNumber
          *      line number where the exception occurred.
@@ -91,7 +92,7 @@
          * Clones this exception.  This is useful for cases where you need
          * to preserve the type of the original exception as well as the message.
          * All subclasses should override.
-         * 
+         *
          * @return A deep copy of this exception.
          */
         virtual CertificateExpiredException* clone() const{

Modified: activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/security/cert/CertificateNotYetValidException.h
URL: http://svn.apache.org/viewvc/activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/security/cert/CertificateNotYetValidException.h?rev=777039&r1=777038&r2=777039&view=diff
==============================================================================
--- activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/security/cert/CertificateNotYetValidException.h (original)
+++ activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/security/cert/CertificateNotYetValidException.h Thu May 21 10:26:09 2009
@@ -18,6 +18,7 @@
 #ifndef _DECAF_SECURITY_CERT_CERTIFICATENOTYETVALIDEXCEPTION_H_
 #define _DECAF_SECURITY_CERT_CERTIFICATENOTYETVALIDEXCEPTION_H_
 
+#include <decaf/util/Config.h>
 #include <decaf/security/cert/CertificateException.h>
 
 namespace decaf{
@@ -25,8 +26,8 @@
 namespace cert{
 
     /*
-     * Certificate is not yet valid exception. This is thrown whenever the 
-     * current Date or the specified Date  is before the notBefore 
+     * Certificate is not yet valid exception. This is thrown whenever the
+     * current Date or the specified Date  is before the notBefore
      * date/time in the Certificate validity period.
      */
     class DECAF_API CertificateNotYetValidException : public CertificateException
@@ -64,8 +65,8 @@
          * Constructor - Initializes the file name and line number where
          * this message occured.  Sets the message to report, using an
          * optional list of arguments to parse into the message
-         * 
-         * @param file 
+         *
+         * @param file
          *      name where exception occurs
          * @param lineNumber
          *      line number where the exception occurred.
@@ -91,7 +92,7 @@
          * Clones this exception.  This is useful for cases where you need
          * to preserve the type of the original exception as well as the message.
          * All subclasses should override.
-         * 
+         *
          * @return A deep copy of this exception.
          */
         virtual CertificateNotYetValidException* clone() const{

Modified: activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/security/cert/CertificateParsingException.h
URL: http://svn.apache.org/viewvc/activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/security/cert/CertificateParsingException.h?rev=777039&r1=777038&r2=777039&view=diff
==============================================================================
--- activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/security/cert/CertificateParsingException.h (original)
+++ activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/security/cert/CertificateParsingException.h Thu May 21 10:26:09 2009
@@ -18,6 +18,7 @@
 #ifndef _DECAF_SECURITY_CERT_CERTIFICATEPARSINGEXCEPTION_H_
 #define _DECAF_SECURITY_CERT_CERTIFICATEPARSINGEXCEPTION_H_
 
+#include <decaf/util/Config.h>
 #include <decaf/security/cert/CertificateException.h>
 
 namespace decaf{
@@ -25,8 +26,8 @@
 namespace cert{
 
     /*
-     * Certificate Parsing Exception. This is thrown whenever an invalid 
-     * DER-encoded certificate is parsed or unsupported DER features are found 
+     * Certificate Parsing Exception. This is thrown whenever an invalid
+     * DER-encoded certificate is parsed or unsupported DER features are found
      * in the Certificate.
      */
     class DECAF_API CertificateParsingException : public CertificateException
@@ -64,8 +65,8 @@
          * Constructor - Initializes the file name and line number where
          * this message occured.  Sets the message to report, using an
          * optional list of arguments to parse into the message
-         * 
-         * @param file 
+         *
+         * @param file
          *      name where exception occurs
          * @param lineNumber
          *      line number where the exception occurred.
@@ -91,7 +92,7 @@
          * Clones this exception.  This is useful for cases where you need
          * to preserve the type of the original exception as well as the message.
          * All subclasses should override.
-         * 
+         *
          * @return A deep copy of this exception.
          */
         virtual CertificateParsingException* clone() const{

Modified: activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/security/cert/X509Certificate.h
URL: http://svn.apache.org/viewvc/activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/security/cert/X509Certificate.h?rev=777039&r1=777038&r2=777039&view=diff
==============================================================================
--- activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/security/cert/X509Certificate.h (original)
+++ activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/security/cert/X509Certificate.h Thu May 21 10:26:09 2009
@@ -20,6 +20,7 @@
 
 #include <decaf/security/cert/Certificate.h>
 
+#include <decaf/util/Config.h>
 #include <decaf/util/Date.h>
 
 namespace decaf {
@@ -30,49 +31,49 @@
      * Base interface for all identity certificates.
      */
     class DECAF_API X509Certificate : public Certificate {
-    
+
     public:
-        
+
         virtual ~X509Certificate() {}
-        
-        virtual void checkValidity() const 
+
+        virtual void checkValidity() const
             throw(CertificateExpiredException, CertificateNotYetValidException) = 0;
-        
-        virtual void checkValidity(const decaf::util::Date& date) const 
-                    throw(CertificateExpiredException, CertificateNotYetValidException) = 0;                    
-        
+
+        virtual void checkValidity(const decaf::util::Date& date) const
+                    throw(CertificateExpiredException, CertificateNotYetValidException) = 0;
+
         virtual int getBasicConstraints() const = 0;
-        
+
         virtual void getIssuerUniqueID( std::vector<bool>& output ) const = 0;
-        
+
         virtual const X500Principal* getIssuerX500Principal() const = 0;
-        
+
         virtual void getKeyUsage( std::vector<unsigned char>& output ) const = 0;
-        
+
         virtual Date getNotAfter() const = 0;
-        
+
         virtual Date getNotBefore() const = 0;
-        
+
         //virtual BigInteger getSerialNumber() const = 0;
-        
+
         virtual std::string getSigAlgName() const = 0;
-        
+
         virtual std::string getSigAlgOID() const = 0;
-        
+
         virtual void getSigAlgParams( std::vector<unsigned char>& output ) const = 0;
-        
+
         virtual void getSignature( std::vector<unsigned char>& output ) const = 0;
-        
+
         virtual void getSubjectUniqueID( std::vector<bool>& output ) const = 0;
-        
+
         virtual const X500Principal* getSubjectX500Principal() const = 0;
-        
-        virtual void getTBSCertificate( std::vector<unsigned char>& output ) const 
+
+        virtual void getTBSCertificate( std::vector<unsigned char>& output ) const
             throw( CertificateEncodingException ) = 0;
-        
+
         virtual int getVersion() const = 0;
     };
-    
+
 }}}
 
 #endif /*_DECAF_SECURITY_CERT_X509CERTIFICATE_H_*/

Modified: activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/util/AbstractCollection.h
URL: http://svn.apache.org/viewvc/activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/util/AbstractCollection.h?rev=777039&r1=777038&r2=777039&view=diff
==============================================================================
--- activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/util/AbstractCollection.h (original)
+++ activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/util/AbstractCollection.h Thu May 21 10:26:09 2009
@@ -304,10 +304,11 @@
          * @return true if an element was removed as a result of this call
          *
          * @throw UnsupportedOperationException
-         *        if the remove operation is not supported by this collection
-         * @throw IllegalArgumentException.
+         *        if the remove operation is not supported by this collection.
+         * @throw IllegalArgumentException
+         *        If the value is not a valid entry for this Collection.
          */
-        virtual bool remove( const E& value DECAF_UNUSED )
+        virtual bool remove( const E& value )
             throw ( lang::exceptions::UnsupportedOperationException,
                     lang::exceptions::IllegalArgumentException ) {
 

Modified: activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/util/Comparator.h
URL: http://svn.apache.org/viewvc/activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/util/Comparator.h?rev=777039&r1=777038&r2=777039&view=diff
==============================================================================
--- activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/util/Comparator.h (original)
+++ activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/util/Comparator.h Thu May 21 10:26:09 2009
@@ -51,7 +51,7 @@
          *
          * @return true if the vale of left is less than the value of right.
          */
-        virtual bool operator() ( const T&, const T& ) const = 0;
+        virtual bool operator() ( const T& left, const T& right ) const = 0;
 
         /**
          * Compares its two arguments for order. Returns a negative integer, zero,

Modified: activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/util/List.h
URL: http://svn.apache.org/viewvc/activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/util/List.h?rev=777039&r1=777038&r2=777039&view=diff
==============================================================================
--- activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/util/Map.h (original)
+++ activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/util/Map.h Thu May 21 10:26:09 2009
@@ -32,8 +32,8 @@
      * a more user-friendly interface and to provide common
      * functions that do not exist in std::map.
      */
-    template <typename K, typename V, typename COMPARATOR = std::less<K> > 
-	class Map : public concurrent::Synchronizable {
+    template <typename K, typename V, typename COMPARATOR = std::less<K> >
+    class Map : public concurrent::Synchronizable {
     public:
 
         class Entry {
@@ -120,10 +120,21 @@
          * @param key The search key.
          * @return A reference to the value for the given key.
          *
-         * @throws NoSuchElementException
+         * @throws NoSuchElementException if the key requests doesn't exist in the Map.
          */
         virtual V& get( const K& key )
             throw( lang::exceptions::NoSuchElementException ) = 0;
+
+        /**
+         * Gets the value mapped to the specified key in the Map.  If there is no
+         * element in the map whose key is equivalent to the key provided then a
+         * NoSuchElementException is thrown.
+         *
+         * @param key The search key.
+         * @return A {const} reference to the value for the given key.
+         *
+         * @throws NoSuchElementException if the key requests doesn't exist in the Map.
+         */
         virtual const V& get( const K& key ) const
             throw( lang::exceptions::NoSuchElementException ) = 0;
 
@@ -139,8 +150,12 @@
 
         /**
          * Stores a copy of the Mappings contained in the other Map in this one.
-         * @param key The target key.
-         * @param value The value to be set.
+         *
+         * @param other
+         *      A Map instance whose elements are to all be inserted in this Map.
+         *
+         * @throws UnsupportedOperationException
+         *      If the implementing class does not support the putAll operation.
          */
         virtual void putAll( const Map<K,V,COMPARATOR>& other )
             throw ( decaf::lang::exceptions::UnsupportedOperationException ) = 0;
@@ -169,7 +184,7 @@
          * Iterator.remove, Set.remove, removeAll, retainAll and clear operations. It does not
          * support the add or addAll operations.
          */
-
+        // TODO
 
         /**
          * @return the entire set of keys in this map as a std::vector.

Modified: activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/util/Properties.h
URL: http://svn.apache.org/viewvc/activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/util/Properties.h?rev=777039&r1=777038&r2=777039&view=diff
==============================================================================
--- activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/util/Properties.h (original)
+++ activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/util/Properties.h Thu May 21 10:26:09 2009
@@ -312,7 +312,7 @@
          * @throw IOException if there is an error while writing from the stream.
          * @throw NullPointerException if the passed stream is Null.
          */
-        void store( decaf::io::OutputStream* out, const std::string& comments )
+        void store( decaf::io::OutputStream* out, const std::string& comment )
             throw( decaf::io::IOException,
                    decaf::lang::exceptions::NullPointerException );
 

Modified: activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/util/Random.h
URL: http://svn.apache.org/viewvc/activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/util/Random.h?rev=777039&r1=777038&r2=777039&view=diff
==============================================================================
--- activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/util/Random.h (original)
+++ activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/util/Random.h Thu May 21 10:26:09 2009
@@ -118,7 +118,7 @@
          * Pseudo-randomly generates (approximately) a normally
          * distributed <code>double</code> value with mean 0.0 and a
          * standard deviation value of <code>1.0</code> using the <i>polar
-         * method<i> of G. E. P. Box, M.  E. Muller, and G. Marsaglia, as
+         * method</i> of G. E. P. Box, M.  E. Muller, and G. Marsaglia, as
          * described by Donald E. Knuth in <i>The Art of Computer
          * Programming, Volume 2: Seminumerical Algorithms</i>, section
          * 3.4.1, subsection C, algorithm P

Modified: activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/util/Set.h
URL: http://svn.apache.org/viewvc/activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/util/Set.h?rev=777039&r1=777038&r2=777039&view=diff
==============================================================================
--- activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/util/Set.h (original)
+++ activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/util/Set.h Thu May 21 10:26:09 2009
@@ -38,6 +38,8 @@
      * Note: Great care must be exercised if mutable objects are used as set elements.
      * The behavior of a set is not specified if the value of an object is changed in a
      * manner that affects equals comparisons while the object is an element in the set.
+     *
+     * @since 1.0
      */
     template <typename E>
     class Set : public decaf::util::AbstractCollection<E> {

Modified: activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/util/StlMap.h
URL: http://svn.apache.org/viewvc/activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/util/StlMap.h?rev=777039&r1=777038&r2=777039&view=diff
==============================================================================
--- activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/util/StlMap.h (original)
+++ activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/util/StlMap.h Thu May 21 10:26:09 2009
@@ -32,6 +32,8 @@
      * Map template that wraps around a std::map to provide
      * a more user-friendly interface and to provide common
      * functions that do not exist in std::map.
+     *
+     * @since 1.0
      */
     template <typename K, typename V, typename COMPARATOR = std::less<K> >
     class StlMap : public Map<K, V, COMPARATOR> {
@@ -74,6 +76,9 @@
             return this->valueMap == source.valueMap;
         }
 
+        /**
+         * {@inheritDoc}
+         */
         virtual bool equals( const Map<K,V,COMPARATOR>& source ) const {
             std::vector<K> keys = source.keySet();
 
@@ -99,6 +104,9 @@
             this->valueMap.insert( source.valueMap.begin(), source.valueMap.end() );
         }
 
+        /**
+         * {@inheritDoc}
+         */
         virtual void copy( const Map<K,V,COMPARATOR>& source ) {
             this->clear();
             this->putAll( source );
@@ -168,6 +176,10 @@
 
             return iter->second;
         }
+
+        /**
+         * {@inheritDoc}
+         */
         virtual const V& get( const K& key ) const
             throw( lang::exceptions::NoSuchElementException ) {
 
@@ -198,6 +210,10 @@
 
             this->valueMap.insert( other.valueMap.begin(), other.valueMap.end() );
         }
+
+        /**
+         * {@inheritDoc}
+         */
         virtual void putAll( const Map<K,V,COMPARATOR>& other )
             throw ( decaf::lang::exceptions::UnsupportedOperationException ) {
 

Modified: activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/util/StringTokenizer.h
URL: http://svn.apache.org/viewvc/activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/util/StringTokenizer.h?rev=777039&r1=777038&r2=777039&view=diff
==============================================================================
--- activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/util/StringTokenizer.h (original)
+++ activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/util/StringTokenizer.h Thu May 21 10:26:09 2009
@@ -55,9 +55,9 @@
          * Note that if delim is "", this constructor does not throw an
          * exception. However, trying to invoke other methods on the resulting
          * StringTokenizer may result in an Exception.
-         * @param string to tokenize
-         * @param String containing the delimiters
-         * @param boolean indicating if the delimiters are returned as tokens
+         * @param str - The string to tokenize
+         * @param delim - String containing the delimiters
+         * @param returnDelims - boolean indicating if the delimiters are returned as tokens
          */
         StringTokenizer( const std::string& str,
                          const std::string& delim = " \t\n\r\f",
@@ -83,7 +83,7 @@
         /**
          * Returns the next token from this string tokenizer.
          * @return string value of next token
-         * @thorws NoSuchElementException
+         * @throws NoSuchElementException
          */
         virtual std::string nextToken()
             throw ( lang::exceptions::NoSuchElementException );
@@ -96,7 +96,7 @@
          * position is returned. The current position is advanced beyond the
          * recognized token. The new delimiter set remains the default after
          * this call.
-         * @param string containing the new set of delimiters
+         * @param delim - string containing the new set of delimiters
          * @return next string in the token list
          * @throw NoSuchElementException
          */
@@ -106,7 +106,7 @@
         /**
          * Grab all remaining tokens in the String and return them
          * in the vector that is passed in by reference.
-         * @param vector to place token strings in
+         * @param array - vector to place token strings in
          * @return number of string placed into the vector
          */
         virtual unsigned int toArray( std::vector< std::string >& array );
@@ -122,9 +122,9 @@
          * is using to tokenizer the string.  If set to "", no change is made
          * If set the return Delims will set if this Tokenizer will return
          * delimiters as tokens. Defaults to false.
-         * @param New String to tokenize or "", defaults to ""
-         * @param New Delimiter String to use or "", defaults to ""
-         * @param Should the Tokenizer return delimiters as Tokens, default false
+         * @param str - New String to tokenize or "", defaults to ""
+         * @param delim - New Delimiter String to use or "", defaults to ""
+         * @param returnDelims - Should the Tokenizer return delimiters as Tokens, default false
          */
         virtual void reset( const std::string& str = "",
                             const std::string& delim = "",

Modified: activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/util/concurrent/BrokenBarrierException.h
URL: http://svn.apache.org/viewvc/activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/util/concurrent/BrokenBarrierException.h?rev=777039&r1=777038&r2=777039&view=diff
==============================================================================
--- activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/util/concurrent/BrokenBarrierException.h (original)
+++ activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/util/concurrent/BrokenBarrierException.h Thu May 21 10:26:09 2009
@@ -27,18 +27,19 @@
      * Exception thrown when a thread tries to wait upon a barrier that is in a broken
      * state, or which enters the broken state while the thread is waiting.
      */
-    class DECAF_API BrokenBarrierException : public decaf::lang::Exception
-    {
+    class DECAF_API BrokenBarrierException : public decaf::lang::Exception {
     public:
 
         /**
-         * Default Constructor
+         * Default Constructor.
          */
         BrokenBarrierException() throw() : decaf::lang::Exception() {}
 
         /**
-         * Conversion Constructor from some other Exception
-         * @param An exception that should become this type of Exception
+         * Conversion Constructor from some other Exception.
+         *
+         * @param ex
+         *      An exception that should become this type of Exception
          */
         BrokenBarrierException( const decaf::lang::Exception& ex ) throw()
         : decaf::lang::Exception()
@@ -47,7 +48,10 @@
         }
 
         /**
-         * Copy Constructor
+         * Copy Constructor.
+         *
+         * @param ex
+         *      The Exception to copy in this new instance.
          */
         BrokenBarrierException( const BrokenBarrierException& ex ) throw()
         : decaf::lang::Exception()
@@ -67,10 +71,10 @@
          * Constructor - Initializes the file name and line number where
          * this message occurred.  Sets the message to report, using an
          * optional list of arguments to parse into the message
-         * @param file name where exception occurs
-         * @param line number where the exception occurred.
-         * @param message to report
-         * @param list of primitives that are formatted into the message
+         * @param file - The file name where exception occurs
+         * @param lineNumber - The line number where the exception occurred.
+         * @param msg - The message to report
+         * @param ... - list of primitives that are formatted into the message
          */
         BrokenBarrierException( const char* file, const int lineNumber,
                                 const char* msg, ... ) throw()
@@ -89,11 +93,11 @@
          * Constructor - Initializes the file name and line number where
          * this message occurred.  Sets the message to report, using an
          * optional list of arguments to parse into the message
-         * @param file name where exception occurs
-         * @param line number where the exception occurred.
-         * @param cause The exception that was the cause for this one to be thrown.
-         * @param message to report
-         * @param list of primitives that are formatted into the message
+         * @param file - The file name where exception occurs
+         * @param lineNumber - The line number where the exception occurred.
+         * @param cause - The exception that was the cause for this one to be thrown.
+         * @param msg - The message to report
+         * @param ... - list of primitives that are formatted into the message
          */
         BrokenBarrierException( const char* file, const int lineNumber,
                                 const std::exception* cause,
@@ -112,14 +116,13 @@
          * Clones this exception.  This is useful for cases where you need
          * to preserve the type of the original exception as well as the message.
          * All subclasses should override.
+         *
+         * @returns a new instance of an exception that is a clone of this one.
          */
         virtual BrokenBarrierException* clone() const{
             return new BrokenBarrierException( *this );
         }
 
-        /**
-         * Destructor
-         */
         virtual ~BrokenBarrierException() throw() {}
 
     };

Modified: activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/util/concurrent/CancellationException.h
URL: http://svn.apache.org/viewvc/activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/util/concurrent/CancellationException.h?rev=777039&r1=777038&r2=777039&view=diff
==============================================================================
--- activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/util/concurrent/CancellationException.h (original)
+++ activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/util/concurrent/CancellationException.h Thu May 21 10:26:09 2009
@@ -27,8 +27,7 @@
      * Exception indicating that the result of a value-producing task, such as a
      * FutureTask, cannot be retrieved because the task was canceled.
      */
-    class DECAF_API CancellationException : public decaf::lang::Exception
-    {
+    class DECAF_API CancellationException : public decaf::lang::Exception {
     public:
 
         /**
@@ -38,7 +37,8 @@
 
         /**
          * Conversion Constructor from some other Exception
-         * @param An exception that should become this type of Exception
+         *
+         * @param ex An exception that should become this type of Exception
          */
         CancellationException( const decaf::lang::Exception& ex ) throw()
         : decaf::lang::Exception()
@@ -48,6 +48,8 @@
 
         /**
          * Copy Constructor
+         *
+         * @param ex - The Exception to copy in this new instance.
          */
         CancellationException( const CancellationException& ex ) throw()
         : decaf::lang::Exception()
@@ -67,10 +69,10 @@
          * Constructor - Initializes the file name and line number where
          * this message occurred.  Sets the message to report, using an
          * optional list of arguments to parse into the message
-         * @param file name where exception occurs
-         * @param line number where the exception occurred.
-         * @param message to report
-         * @param list of primitives that are formatted into the message
+         * @param file - The file name where exception occurs
+         * @param lineNumber - The line number where the exception occurred.
+         * @param msg - The message to report
+         * @param ... - list of primitives that are formatted into the message
          */
         CancellationException( const char* file, const int lineNumber,
                                const char* msg, ... ) throw()
@@ -89,11 +91,11 @@
          * Constructor - Initializes the file name and line number where
          * this message occurred.  Sets the message to report, using an
          * optional list of arguments to parse into the message
-         * @param file name where exception occurs
-         * @param line number where the exception occurred.
-         * @param cause The exception that was the cause for this one to be thrown.
-         * @param message to report
-         * @param list of primitives that are formatted into the message
+         * @param file - The file name where exception occurs
+         * @param lineNumber - The line number where the exception occurred.
+         * @param cause - The exception that was the cause for this one to be thrown.
+         * @param msg - The message to report
+         * @param ... - list of primitives that are formatted into the message
          */
         CancellationException( const char* file, const int lineNumber,
                                 const std::exception* cause,
@@ -112,14 +114,13 @@
          * Clones this exception.  This is useful for cases where you need
          * to preserve the type of the original exception as well as the message.
          * All subclasses should override.
+         *
+         * @returns a new instance of an exception that is a clone of this one.
          */
         virtual CancellationException* clone() const{
             return new CancellationException( *this );
         }
 
-        /**
-         * Destructor
-         */
         virtual ~CancellationException() throw() {}
 
     };

Modified: activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/util/concurrent/Concurrent.h
URL: http://svn.apache.org/viewvc/activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/util/concurrent/Concurrent.h?rev=777039&r1=777038&r2=777039&view=diff
==============================================================================
--- activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/util/concurrent/Concurrent.h (original)
+++ activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/util/concurrent/Concurrent.h Thu May 21 10:26:09 2009
@@ -26,12 +26,12 @@
 
 /**
  * The synchronized macro defines a mechanism for snycronizing
- * a scetion of code.  The macro must be passed an object that
+ * a section of code.  The macro must be passed an object that
  * implements the Syncronizable interface.
  *
  * The macro works by creating a for loop that will loop exactly
  * once, creating a Lock object that is scoped to the loop.  Once
- * the loop conpletes and exits the Lock object goes out of scope
+ * the loop completes and exits the Lock object goes out of scope
  * releasing the lock on object W.  For added safety the if else
  * is used because not all compiles restrict the lifetime of
  * loop variables to the loop, they will however restrict them
@@ -39,7 +39,7 @@
  *
  * The macro would be used as follows.
  *
- * <Syncronizable> X;
+ * Syncronizable X;
  *
  * somefunction()
  * {

Modified: activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/util/concurrent/ConcurrentStlMap.h
URL: http://svn.apache.org/viewvc/activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/util/concurrent/ConcurrentStlMap.h?rev=777039&r1=777038&r2=777039&view=diff
==============================================================================
--- activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/util/concurrent/ConcurrentStlMap.h (original)
+++ activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/util/concurrent/ConcurrentStlMap.h Thu May 21 10:26:09 2009
@@ -39,6 +39,8 @@
      * implementations synchronizes all methods such that any call to this class
      * will block if another thread is already holding a lock, much like the
      * Java HashTable.
+     *
+     * @since 1.0
      */
     template <typename K, typename V, typename COMPARATOR = std::less<K> >
     class ConcurrentStlMap : public ConcurrentMap<K, V, COMPARATOR> {
@@ -207,6 +209,10 @@
             throw lang::exceptions::NoSuchElementException(
                 __FILE__, __LINE__, "Key does not exist in map" );
         }
+
+        /**
+         * {@inheritDoc}
+         */
         virtual const V& get( const K& key ) const
             throw( lang::exceptions::NoSuchElementException ) {
 
@@ -244,6 +250,10 @@
                 this->valueMap.insert( other.valueMap.begin(), other.valueMap.end() );
             }
         }
+
+        /**
+         * {@inheritDoc}
+         */
         virtual void putAll( const Map<K,V,COMPARATOR>& other )
             throw ( decaf::lang::exceptions::UnsupportedOperationException ) {
 
@@ -280,7 +290,6 @@
             return result;
         }
 
-
         /**
          * {@inheritDoc}
          */

Modified: activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/util/concurrent/ExecutionException.h
URL: http://svn.apache.org/viewvc/activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/util/concurrent/ExecutionException.h?rev=777039&r1=777038&r2=777039&view=diff
==============================================================================
--- activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/util/concurrent/ExecutionException.h (original)
+++ activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/util/concurrent/ExecutionException.h Thu May 21 10:26:09 2009
@@ -28,8 +28,7 @@
      * throwing an exception. This exception can be inspected using the Throwable.getCause()
      * method.
      */
-    class DECAF_API ExecutionException : public decaf::lang::Exception
-    {
+    class DECAF_API ExecutionException : public decaf::lang::Exception {
     public:
 
         /**
@@ -39,7 +38,7 @@
 
         /**
          * Conversion Constructor from some other Exception
-         * @param An exception that should become this type of Exception
+         * @param ex - An exception that should become this type of Exception
          */
         ExecutionException( const decaf::lang::Exception& ex ) throw()
         : decaf::lang::Exception()
@@ -49,6 +48,8 @@
 
         /**
          * Copy Constructor
+         *
+         * @param ex - The Exception to copy in this new instance.
          */
         ExecutionException( const ExecutionException& ex ) throw()
         : decaf::lang::Exception()
@@ -58,6 +59,7 @@
 
         /**
          * Constructor
+         *
          * @param cause Pointer to the exception that caused this one to
          * be thrown, the object is cloned caller retains ownership.
          */
@@ -68,10 +70,10 @@
          * Constructor - Initializes the file name and line number where
          * this message occurred.  Sets the message to report, using an
          * optional list of arguments to parse into the message
-         * @param file name where exception occurs
-         * @param line number where the exception occurred.
-         * @param message to report
-         * @param list of primitives that are formatted into the message
+         * @param file - The file name where exception occurs
+         * @param lineNumber - The line number where the exception occurred.
+         * @param msg - The message to report
+         * @param ...  - The list of primitives that are formatted into the message
          */
         ExecutionException( const char* file, const int lineNumber,
                             const char* msg, ... ) throw()
@@ -90,11 +92,11 @@
          * Constructor - Initializes the file name and line number where
          * this message occurred.  Sets the message to report, using an
          * optional list of arguments to parse into the message
-         * @param file name where exception occurs
-         * @param line number where the exception occurred.
-         * @param cause The exception that was the cause for this one to be thrown.
-         * @param message to report
-         * @param list of primitives that are formatted into the message
+         * @param file - The file name where exception occurs
+         * @param lineNumber - The line number where the exception occurred.
+         * @param cause - The exception that was the cause for this one to be thrown.
+         * @param msg - The message to report
+         * @param ... - list of primitives that are formatted into the message
          */
         ExecutionException( const char* file, const int lineNumber,
                             const std::exception* cause,
@@ -113,14 +115,13 @@
          * Clones this exception.  This is useful for cases where you need
          * to preserve the type of the original exception as well as the message.
          * All subclasses should override.
+         *
+         * @returns a new instance of an exception that is a clone of this one.
          */
         virtual ExecutionException* clone() const{
             return new ExecutionException( *this );
         }
 
-        /**
-         * Destructor
-         */
         virtual ~ExecutionException() throw() {}
 
     };

Modified: activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/util/concurrent/PooledThreadListener.h
URL: http://svn.apache.org/viewvc/activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/util/concurrent/PooledThreadListener.h?rev=777039&r1=777038&r2=777039&view=diff
==============================================================================
--- activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/util/concurrent/PooledThreadListener.h (original)
+++ activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/util/concurrent/PooledThreadListener.h Thu May 21 10:26:09 2009
@@ -26,26 +26,30 @@
 
     class PooledThread;
 
-    class DECAF_API PooledThreadListener
-    {
+    /**
+     * Abstract Listener Interface for users of <code>ThreadPool</code>.
+     *
+     * The implementor of this class receives events related to the execution and termination
+     * of threads running in the ThreadPool.
+     *
+     * @since 1.0
+     */
+    class DECAF_API PooledThreadListener {
     public:
 
-        /**
-         * Destructor
-         */
         virtual ~PooledThreadListener() {}
 
         /**
          * Called by a pooled thread when it is about to begin
          * executing a new task.
-         * @param Pointer to the Pooled Thread that is making this call
+         * @param thread - Pointer to the Pooled Thread that is making this call
          */
         virtual void onTaskStarted( PooledThread* thread ) = 0;
 
         /**
          * Called by a pooled thread when it has completed a task
          * and is going back to waiting for another task to run
-         * @param Pointer the the Pooled Thread that is making this call.
+         * @param thread - Pointer the the Pooled Thread that is making this call.
          */
         virtual void onTaskCompleted( PooledThread* thread ) = 0;
 
@@ -54,8 +58,8 @@
          * while running a user task, after receiving this notification
          * the callee should assume that the PooledThread is now no longer
          * running.
-         * @param Pointer to the Pooled Thread that is making this call
-         * @param The Exception that occured.
+         * @param thread - Pointer to the Pooled Thread that is making this call
+         * @param ex - The Exception that occurred.
          */
         virtual void onTaskException( PooledThread* thread,
                                       lang::Exception& ex) = 0;

Modified: activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/util/concurrent/RejectedExecutionException.h
URL: http://svn.apache.org/viewvc/activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/util/concurrent/RejectedExecutionException.h?rev=777039&r1=777038&r2=777039&view=diff
==============================================================================
--- activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/util/concurrent/RejectedExecutionException.h (original)
+++ activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/util/concurrent/RejectedExecutionException.h Thu May 21 10:26:09 2009
@@ -47,6 +47,8 @@
 
         /**
          * Copy Constructor
+         *
+         * @param ex - The Exception to copy in this new instance.
          */
         RejectedExecutionException( const RejectedExecutionException& ex ) throw()
         : decaf::lang::Exception() {
@@ -65,10 +67,10 @@
          * Constructor - Initializes the file name and line number where
          * this message occurred.  Sets the message to report, using an
          * optional list of arguments to parse into the message
-         * @param file The file name where exception occurs
-         * @param lineNumber The lie number where the exception occurred.
-         * @param msg The Message to report
-         * @param ... list of primitives that are formatted into the message
+         * @param file - The file name where exception occurs
+         * @param lineNumber - The line number where the exception occurred.
+         * @param msg - The message to report
+         * @param ... - list of primitives that are formatted into the message
          */
         RejectedExecutionException( const char* file, const int lineNumber,
                                     const char* msg, ... ) throw()
@@ -86,11 +88,11 @@
          * Constructor - Initializes the file name and line number where
          * this message occurred.  Sets the message to report, using an
          * optional list of arguments to parse into the message
-         * @param file The file name where exception occurs
-         * @param lineNumber The lie number where the exception occurred.
-         * @param cause The exception that was the cause for this one to be thrown.
-         * @param msg The Message to report
-         * @param ... list of primitives that are formatted into the message
+         * @param file - The file name where exception occurs
+         * @param lineNumber - The line number where the exception occurred.
+         * @param cause - The exception that was the cause for this one to be thrown.
+         * @param msg - The message to report
+         * @param ... - list of primitives that are formatted into the message
          */
         RejectedExecutionException( const char* file, const int lineNumber,
                                     const std::exception* cause,

Modified: activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/util/concurrent/locks/Condition.h
URL: http://svn.apache.org/viewvc/activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/util/concurrent/locks/Condition.h?rev=777039&r1=777038&r2=777039&view=diff
==============================================================================
--- activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/util/concurrent/locks/Condition.h (original)
+++ activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/util/concurrent/locks/Condition.h Thu May 21 10:26:09 2009
@@ -318,7 +318,7 @@
             throw( decaf::lang::exceptions::InterruptedException,
                    decaf::lang::exceptions::IllegalMonitorStateException ) = 0;
 
-        /**
+        /*
          * Causes the current thread to wait until it is signalled or interrupted, or the
          * specified deadline elapses.
          * <p>

Modified: activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/util/concurrent/locks/ReadWriteLock.h
URL: http://svn.apache.org/viewvc/activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/util/concurrent/locks/ReadWriteLock.h?rev=777039&r1=777038&r2=777039&view=diff
==============================================================================
--- activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/util/concurrent/locks/ReadWriteLock.h (original)
+++ activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/util/concurrent/locks/ReadWriteLock.h Thu May 21 10:26:09 2009
@@ -91,12 +91,13 @@
 
         /**
          * Returns the lock used for reading.
+         * @returns the lock used for reading.
          */
         virtual Lock& readLock() = 0;
 
         /**
          * Returns the lock used for writing.
-         * @rerturns the lock used for writing.
+         * @returns the lock used for writing.
          */
         virtual Lock& writeLock() = 0;
--- activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/util/List.h (original)
+++ activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/util/List.h Thu May 21 10:26:09 2009
@@ -145,15 +145,17 @@
          * operation is in progress. (Note that this will occur if the specified collection
          * is this list, and it's nonempty.)
          *
          * @param index index at which to insert the first element from the specified collection
          * @param c collection containing elements to be added to this list
          *
          * @return true if this list changed as a result of the call
          *
          * @throw IndexOutOfBoundsException - if the index is greater than size
          * @throw UnsupportedOperationException - If the collection is non-modifiable.
          */
-        virtual bool addAll( std::size_t index, const Collection<E>& c )
+        virtual bool addAll( std::size_t index, const Collection<E>& source )
             throw ( decaf::lang::exceptions::UnsupportedOperationException,
                     decaf::lang::exceptions::IndexOutOfBoundsException ) = 0;
 
@@ -145,15 +145,17 @@
          * is this list, and it's nonempty.)
          *
-         * @param index index at which to insert the first element from the specified collection
-         * @param c collection containing elements to be added to this list
+         * @param index
+         *      The index at which to insert the first element from the specified collection
+         * @param source
+         *      The Collection containing elements to be added to this list
          *
          * @return true if this list changed as a result of the call

Modified: activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/util/Map.h
URL: http://svn.apache.org/viewvc/activemq/activemq-cpp/trunk/activemq-cpp/src/main/decaf/util/Map.h?rev=777039&r1=777038&r2=777039&view=diff
==============================================================================